==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_prefs.php <==
<?php

/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|    	Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_prefs.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/

define("PRFLAN_1", "Site Information");
define("PRFLAN_2", "Site Name");
define("PRFLAN_3", "Site URL");
define("PRFLAN_4", "Site Link Button");
define("PRFLAN_5", "Site Tagline");
define("PRFLAN_6", "Site Description");
define("PRFLAN_7", "Main site admin");
define("PRFLAN_8", "Main site admin email");
define("PRFLAN_9", "Site Disclaimer");
define("PRFLAN_10", "Theme");
define("PRFLAN_11", "Site Theme");
define("PRFLAN_12", "Click here to preview themes");
define("PRFLAN_13", "Display Information");
define("PRFLAN_14", "Display theme information?");
define("PRFLAN_15", "Display render time?");
define("PRFLAN_16", "Display sql queries?");
define("PRFLAN_17", "Compress Site Output Using gzip");
define("PRFLAN_19", "Signup Page Options");
define("PRFLAN_21", "Date Display options");
define("PRFLAN_22", "Short date format");
define("PRFLAN_23", "Long date format");
define("PRFLAN_24", "Forum date format");
define("PRFLAN_25", "For more information on date formats see the");
define("PRFLAN_26", "Time offset");
define("PRFLAN_27", "Example, if you set this to +2, all times on your site will have two hours added to them");
define("PRFLAN_28", "User Registration/Posting");
define("PRFLAN_29", "Activate user registration system?");
define("PRFLAN_30", "allow users to register as members on your site");
//define("PRFLAN_31", "Use email verification for signups?");
define("PRFLAN_32", "Allow anonymous posting?");
define("PRFLAN_33", "switch this off to allow only registered members to post comments etc");
define("PRFLAN_35", "Enable flood protection?");
define("PRFLAN_36", "Flood timeout");
define("PRFLAN_37", "Auto Ban");
define("PRFLAN_38", "Time required in seconds between 2 posts for areas where users can post (chatbox, forums...). if a user post too fast, he will be redirected to the homepage");
define("PRFLAN_40", "Filter profanities?");
define("PRFLAN_41", "if checked swearing will be replaced with string below");
define("PRFLAN_42", "Replace string");
define("PRFLAN_43", "Filter words");
define("PRFLAN_44", "words to censor, separate with a comma");
define("PRFLAN_45", "Use COPPA on signup page?");
define("PRFLAN_46", "for more info on COPPA see");
define("PRFLAN_47", "Security &amp; Protection");
define("PRFLAN_48", "User Tracking method");
define("PRFLAN_49", "Cookies");
define("PRFLAN_50", "Sessions");
define("PRFLAN_52", "Save Changes");
define("PRFLAN_53", "Site Preferences");
define("PRFLAN_55", "Cookie name (if cookies selected)");
define("PRFLAN_56", "Timezone");
define("PRFLAN_58", "Restrict website to members only");
define("PRFLAN_59", "ticking will restrict all areas apart from the front page and signup page to members only");
define("PRFLAN_60", "Enable SSL");
define("PRFLAN_61", "Only enable SSL if <b>you are sure you know what you are doing!</b>");
define("PRFLAN_76", "Enable Image-code verification during signup.");
define("PRFLAN_77", "Admin Display Options ");
define("PRFLAN_78", "Leave blank to disable");
define("PRFLAN_80", "Click here to view");
define("PRFLAN_81", "Enable Image-code verification during login.");
define("PRFLAN_83", "example");
define("PRFLAN_87", "Comments");
define("PRFLAN_88", "Turn on nested comments");
define("PRFLAN_89", "Display new comment icon");
define("PRFLAN_90", "Allow posters to edit their comments");

define("CUSTSIG_1", "Settings Saved!");
define("CUSTSIG_2", "Real Name:");
define("CUSTSIG_3", "Website:");
define("CUSTSIG_4", "Birthday:");
define("CUSTSIG_5", "Location:");
define("CUSTSIG_6", "Signature:");
define("CUSTSIG_7", "Avatar:");
define("CUSTSIG_8", "Time-Zone:");
define("CUSTSIG_12", "Hide");
define("CUSTSIG_13", "Fields");
define("CUSTSIG_14", "Display");
define("CUSTSIG_15", "Required");
define("CUSTSIG_16", "Minimum Length for Passwords");
define("CUSTSIG_17", "Subscribe to content/mailouts");
define("CUSTSIG_18", "Disallow usernames");
define("CUSTSIG_19", "usernames containing the following text will be rejected, separate entries by commas");

define("PRFLAN_91", "If someone is attacking your site by multiple requests to your server, his IP will be automatically banned ! Best done with server config if possible!!!");
define("PRFLAN_92", "Secure signup verification -- hide password in email?");
define("PRFLAN_93", "strftime function page at php.net");
define("PRFLAN_94", "here");
define("PRFLAN_95", "Display plugins info:");
define("PRFLAN_96", "Will display info on all admin pages for each plugin supporting this type of feature");
define("PRFLAN_97", "Unique 'Plugins info' menu:");
define("PRFLAN_98", "If unchecked, each plugin will display its own info in an individual menu. If checked all info will be displayed in one menu.");
define("PRFLAN_101", "Text Rendering");
define("PRFLAN_102", "Replace clickable URLs");
define("PRFLAN_103", "If ticked, and 'Make Clickable' (above) is also ticked, posted URLs or Email addresses are displayed as a hyperlink using text from the textboxes below. This keeps very long URLs/Emails from breaking layout.");
define("PRFLAN_104", "URL replacement text");
define("PRFLAN_105", "Replacement visible text for clickable URLs. Image can be used by using &lt;img&gt; tag, with full path to image");
define("PRFLAN_106", "Core preferences saved to database.");
define("PRFLAN_107", "Email link replace text");
define("PRFLAN_108", "text to replace email links with, image can be used by using &lt;img&gt; tag, with full path to image");
define("PRFLAN_109", "Wrap long words in main text");
define("PRFLAN_110", "words longer than the length entered will be wrapped onto a new line");
define("PRFLAN_111", "Wrap long words in menu text");
define("PRFLAN_112", "On");
define("PRFLAN_113", "Off");
define("PRFLAN_116", "Allow HTML posting");
define("PRFLAN_117", "This will allow users to post HTML code anywhere on the site, select the userclass to allow this.");
define("PRFLAN_118", "Use Geshi for syntax highlighting");
define("PRFLAN_119", "Geshi is an open source multi-language syntax highlighter, see http://qbnz.com/highlighter/ for more information");
define("PRFLAN_120", "Default Geshi syntax language");
define("PRFLAN_121", "if no language is specified in the code bbtag, this language will be used for highlighting");
define("PRFLAN_122", "Enable WYSIWYG textareas");
define("PRFLAN_123", "Will display a what-you-see-is-what-you-get editor in textareas when available. Applies only to Admins and Users that are allowed to post HTML.");
define("PRFLAN_124", "Use 'classic' nextprev look");
define("PRFLAN_125", "Turning this on will show the nextprev pages as 1 2 3 ... 21 22 23, instead of the new look with the dropdown.");
define("PRFLAN_126", "Text to display on signup page");
define("PRFLAN_127", "Make URLs clickable");
define("PRFLAN_128", "Turning this on will convert posted URLs or Email addresses to hyperlinks");
define("PRFLAN_129", "Disallow multiple logins");
define("PRFLAN_130", "Activating this will prevent more than one person logging in with the same username/password (login detail sharing)");
define("PRFLAN_131", "Activate use of [php] bbcode");
define("PRFLAN_132", "Activating this will allow authorized users to post [php] code in certain areas");
define("PRFLAN_133", "GD extension required, not found");
define("PRFLAN_134", "Redirect all requests to site URL");
define("PRFLAN_135", "for example, if your site URL above is set http://foo.com, anyone requesting http://www.foo.com will be redirected to http://foo.com");
define("PRFLAN_136", "Maximum Signups permitted from the same IP address.");
define("PRFLAN_137", "Display Memory Usage");
define("PRFLAN_138", "Enable Image-code verification during forgotten password.");
define("PRFLAN_139", "Display warning when main administrator password hasn't changed for at least 30 days");
define("PRFLAN_140", "Text to display after signup form has been submitted.");
define("PRFLAN_141", "Allow registration using XML User Profiles");
define("PRFLAN_142", "Flood Only");
define("PRFLAN_143", "Failed Login Only");
define("PRFLAN_144", "Flood &amp; Failed Login");
define("PRFLAN_145", "Links in new window");
define("PRFLAN_146", "Tick here to make all links open in a new window (<i>this will apply sitewide</i>). ");
define("PRFLAN_147", "Developer Mode");
define("PRFLAN_148", "Activate developer functions. This is for developers only. Do not use on production sites for security reasons.");
define("PRFLAN_149", "Advanced Features");
define("PRFLAN_150", "Select e107 authentication method");
define("PRFLAN_151", "e107 - No alternate authentication methods installed");

define("PRFLAN_31", "Email Verification");
define("PRFLAN_152", "No Verification");
define("PRFLAN_153", "Admin Approval");
define("PRFLAN_154", "New user verification method <br />If 'Admin Approval' is selected, it is recommended that you enable email notification on user signup <a href='".e_ADMIN."notify.php'>here</a>.");

define("PRFLAN_155", "Display name and login name may be different for");
define("PRFLAN_156", "Reset ALL Display Names");
define("PRFLAN_157", "All Display Names have been reset to the Username");
define("PRFLAN_158", "Display Name maximum length (5..30)");
define("PRFLAN_159", "viewing this page with");

define("PRFLAN_160", "Check remote servers when validating email addresses.");
define("PRFLAN_161", "Disable all comments on the site");

define("PRFLAN_162", "Site Contact Information");
define("PRFLAN_163", "e.g. Company Name, Address, Phone, etc.");

define("PRFLAN_164", "Allow users to email copy of contact email to self");
define("PRFLAN_165", "Possible opening for allowing spam, use with caution");
define("PRFLAN_166", "Show emoticon images on comment form?");

define("PRFLAN_167", "Make entering an email address optional"); // subject to change.
define("PRFLAN_168", "Site Contact Person(s)");
define("PRFLAN_169", "If the chosen group contains more than one person, the user will be asked to select a person from the group.");

define("PRFLAN_170", "Use reverse DNS to allow host banning");
define("PRFLAN_171", "Turning this option on will allow you to ban users by hostname, rather then just IP or email address.  <br />NOTE: This may affect pageload times on some hosts");
define("PRFLAN_172", "Login Name maximum length (10..100)");
define("PRFLAN_173", "Check for E107 updates once/day");

define("PRFLAN_174", "Name for responses to emails from site");
define("PRFLAN_175", "This will appear in the 'From' field of registration and other emails from this site");
define("PRFLAN_176", "Email address for emails from site");
define("PRFLAN_177", "Address specified for replies to emails from this site.");

// Following numbers used for consistency with 0.8
define('PRFLAN_208', 'User class which can email links to items on site');
define('PRFLAN_209', 'Other Features');
define('PRFLAN_210', 'Comments/Posting');


?>

==> e107-1.0.0.tbz: www/e107/e107_languages/English/admin/lan_prefs.php <==
<?php

/*
 * e107 website system
 *
 * Copyright (C) 2002-2010 e107 Inc (e107.org)
 * Released under the terms and conditions of the
 * GNU General Public License (http://www.gnu.org/licenses/gpl.txt)
 *
 * Site preferences - language file
 *
 * $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_prefs.php $
 * $Id: lan_prefs.php 12013 2010-12-18 22:55:22Z e107steved $
 */

define("PRFLAN_1", "Site Information");
define("PRFLAN_2", "Site Name");
define("PRFLAN_3", "Site URL");
define("PRFLAN_4", "Site Link Button");
define("PRFLAN_5", "Site Tagline");
define("PRFLAN_6", "Site Description");
define("PRFLAN_7", "Main site admin");
define("PRFLAN_8", "Main site admin email");
define("PRFLAN_9", "Site Disclaimer");
define("PRFLAN_10", "Theme");
define("PRFLAN_11", "Site Theme");
define("PRFLAN_12", "Click here to preview themes");
define("PRFLAN_13", "Display Information");
define("PRFLAN_14", "Display theme information?");
define("PRFLAN_15", "Display render time?");
define("PRFLAN_16", "Display sql queries?");
define("PRFLAN_17", "Compress Site Output Using gzip");
define("PRFLAN_19", "Signup Page Options");
define("PRFLAN_21", "Date Display options");
define("PRFLAN_22", "Short date format");
define("PRFLAN_23", "Long date format");
define("PRFLAN_24", "Forum date format");
define("PRFLAN_25", "For more information on date formats see the");
define("PRFLAN_26", "Time offset");
define("PRFLAN_27", "Example, if you set this to +2, all times on your site will have two hours added to them");
define("PRFLAN_28", "User Registration/Posting");
define("PRFLAN_29", "Activate user registration system?");
define("PRFLAN_30", "allow users to register as members on your site");
//define("PRFLAN_31", "Use email verification for signups?");
define("PRFLAN_32", "Allow anonymous posting?");
define("PRFLAN_33", "switch this off to allow only registered members to post comments etc");
define("PRFLAN_35", "Enable flood protection?");
define("PRFLAN_36", "Flood timeout");
define("PRFLAN_37", "Auto Ban");
define("PRFLAN_38", "Time required in seconds between 2 posts for areas where users can post (chatbox, forums...). if a user post too fast, he will be redirected to the homepage");
define("PRFLAN_40", "Filter profanities?");
define("PRFLAN_41", "if checked swearing will be replaced with string below");
define("PRFLAN_42", "Replace string");
define("PRFLAN_43", "Filter words");
define("PRFLAN_44", "words to censor, separate with a comma");
define("PRFLAN_45", "Use COPPA on signup page?");
define("PRFLAN_46", "for more info on COPPA see");
define("PRFLAN_47", "Security &amp; Protection");
define("PRFLAN_48", "User Tracking method");
define("PRFLAN_49", "Cookies");
define("PRFLAN_50", "Sessions");
define("PRFLAN_52", "Save Changes");
define("PRFLAN_53", "Site Preferences");
define("PRFLAN_55", "Cookie name (if cookies selected)");
define("PRFLAN_56", "Timezone");
define("PRFLAN_58", "Restrict website to members only");
define("PRFLAN_59", "ticking will restrict all areas apart from the front page and signup page to members only");
define("PRFLAN_60", "Enable SSL");
define("PRFLAN_61", "Only enable SSL if <b>you are sure you know what you are doing!</b>");
define("PRFLAN_76", "Enable Image-code verification during signup.");
define("PRFLAN_77", "Admin Display Options ");
define("PRFLAN_78", "Leave blank to disable");
define("PRFLAN_80", "Click here to view");
define("PRFLAN_81", "Enable Image-code verification during login.");
define("PRFLAN_83", "example");
define("PRFLAN_87", "Comments");
define("PRFLAN_88", "Turn on nested comments");
define("PRFLAN_89", "Display new comment icon");
define("PRFLAN_90", "Allow posters to edit their comments");

define("CUSTSIG_1", "Settings Saved!");
define("CUSTSIG_2", "Real Name:");
define("CUSTSIG_3", "Website:");
define("CUSTSIG_4", "Birthday:");
define("CUSTSIG_5", "Location:");
define("CUSTSIG_6", "Signature:");
define("CUSTSIG_7", "Avatar:");
define("CUSTSIG_8", "Time-Zone:");
define("CUSTSIG_12", "Hide");
define("CUSTSIG_13", "Fields");
define("CUSTSIG_14", "Display");
define("CUSTSIG_15", "Required");
define("CUSTSIG_16", "Minimum Length for Passwords");
define("CUSTSIG_17", "Subscribe to content/mailouts");
define("CUSTSIG_18", "Disallow usernames");
define("CUSTSIG_19", "usernames containing the following text will be rejected, separate entries by commas");

define("PRFLAN_91", "If someone is attacking your site by multiple requests to your server, his IP will be automatically banned ! Best done with server config if possible!!!");
define("PRFLAN_92", "Secure signup verification -- hide password in email?");
define("PRFLAN_93", "strftime function page at php.net");
define("PRFLAN_94", "here");
define("PRFLAN_95", "Display plugins info:");
define("PRFLAN_96", "Will display info on all admin pages for each plugin supporting this type of feature");
define("PRFLAN_97", "Unique 'Plugins info' menu:");
define("PRFLAN_98", "If unchecked, each plugin will display its own info in an individual menu. If checked all info will be displayed in one menu.");
define("PRFLAN_101", "Text Rendering");
define("PRFLAN_102", "Replace clickable URLs");
define("PRFLAN_103", "If ticked, and 'Make Clickable' (above) is also ticked, posted URLs or Email addresses are displayed as a hyperlink using text from the textboxes below. This keeps very long URLs/Emails from breaking layout.");
define("PRFLAN_104", "URL replacement text");
define("PRFLAN_105", "Replacement visible text for clickable URLs. Image can be used by using &lt;img&gt; tag, with full path to image");
define("PRFLAN_106", "Core preferences saved to database.");
define("PRFLAN_107", "Email link replace text");
define("PRFLAN_108", "text to replace email links with, image can be used by using &lt;img&gt; tag, with full path to image");
define("PRFLAN_109", "Wrap long words in main text");
define("PRFLAN_110", "words longer than the length entered will be wrapped onto a new line");
define("PRFLAN_111", "Wrap long words in menu text");
define("PRFLAN_112", "On");
define("PRFLAN_113", "Off");
define("PRFLAN_116", "Class which can post HTML");
define("PRFLAN_117", "This will allow users to post most HTML code anywhere on the site.");
define("PRFLAN_118", "Use Geshi for syntax highlighting");
define("PRFLAN_119", "Geshi is an open source multi-language syntax highlighter, see http://qbnz.com/highlighter/ for more information");
define("PRFLAN_120", "Default Geshi syntax language");
define("PRFLAN_121", "if no language is specified in the code bbtag, this language will be used for highlighting");
define("PRFLAN_122", "Enable WYSIWYG textareas");
define("PRFLAN_123", "Will display a what-you-see-is-what-you-get editor in textareas when available. Applies only to Admins and Users that are allowed to post HTML.");
define("PRFLAN_124", "Use 'classic' nextprev look");
define("PRFLAN_125", "Turning this on will show the nextprev pages as 1 2 3 ... 21 22 23, instead of the new look with the dropdown.");
define("PRFLAN_126", "Text to display on signup page");
define("PRFLAN_127", "Make URLs clickable");
define("PRFLAN_128", "Turning this on will convert posted URLs or Email addresses to hyperlinks");
define("PRFLAN_129", "Disallow multiple logins");
define("PRFLAN_130", "Activating this will prevent more than one person logging in with the same username/password (login detail sharing)");
define("PRFLAN_131", "Activate use of [php] bbcode");
define("PRFLAN_132", "Activating this will allow authorized users to post [php] code in certain areas");
define("PRFLAN_133", "GD extension required, not found");
define("PRFLAN_134", "Redirect all requests to site URL");
define("PRFLAN_135", "for example, if your site URL above is set http://foo.com, anyone requesting http://www.foo.com will be redirected to http://foo.com");
define("PRFLAN_136", "Maximum Signups permitted from the same IP address.");
define("PRFLAN_137", "Display Memory Usage");
define("PRFLAN_138", "Enable Image-code verification during forgotten password.");
define("PRFLAN_139", "Display warning when main administrator password hasn't changed for at least 30 days");
define("PRFLAN_140", "Text to display after signup form has been submitted.");
define("PRFLAN_141", "Allow registration using XML User Profiles");
define("PRFLAN_142", "Flood Only");
define("PRFLAN_143", "Failed Login Only");
define("PRFLAN_144", "Flood &amp; Failed Login");
define("PRFLAN_145", "Links in new window");
define("PRFLAN_146", "Tick here to make all links open in a new window (<i>this will apply sitewide</i>). ");
define("PRFLAN_147", "Developer Mode");
define("PRFLAN_148", "Activate developer functions. This is for developers only. Do not use on production sites for security reasons.");
define("PRFLAN_149", "Advanced Features");
define("PRFLAN_150", "Select e107 authentication method");
define("PRFLAN_151", "e107 - No alternate authentication methods installed");

define("PRFLAN_31", "Email Verification");
define("PRFLAN_152", "No Verification");
define("PRFLAN_153", "Admin Approval");
define("PRFLAN_154", "New user verification method <br />If 'Admin Approval' is selected, it is recommended that you enable email notification on user signup <a href='".e_ADMIN."notify.php'>here</a>.");

define("PRFLAN_155", "Display name and login name may be different for");
define("PRFLAN_156", "Reset ALL Display Names");
define("PRFLAN_157", "All Display Names have been reset to the Username");
define("PRFLAN_158", "Display Name maximum length (5..30)");
define("PRFLAN_159", "viewing this page with");

define("PRFLAN_160", "Check remote servers when validating email addresses.");
define("PRFLAN_161", "Disable all comments on the site");

define("PRFLAN_162", "Site Contact Information");
define("PRFLAN_163", "e.g. Company Name, Address, Phone, etc.");

define("PRFLAN_164", "Allow users to email copy of contact email to self");
define("PRFLAN_165", "Possible opening for allowing spam, use with caution");
define("PRFLAN_166", "Show emoticon images on comment form?");

define("PRFLAN_167", "Make entering an email address optional"); // subject to change.
define("PRFLAN_168", "Site Contact Person(s)");
define("PRFLAN_169", "If the chosen group contains more than one person, the user will be asked to select a person from the group.");

define("PRFLAN_170", "Use reverse DNS to allow host banning");
define("PRFLAN_171", "Turning this option on will allow you to ban users by hostname, rather then just IP or email address.  <br />NOTE: This may affect pageload times on some hosts");
define("PRFLAN_172", "Login Name maximum length (10..100)");
define("PRFLAN_173", "Check for E107 updates once/day");

define("PRFLAN_174", "Name for responses to emails from site");
define("PRFLAN_175", "This will appear in the 'From' field of registration and other emails from this site");
define("PRFLAN_176", "Email address for emails from site");
define("PRFLAN_177", "Address specified for replies to emails from this site.");

// Following numbers used for consistency with 0.8
define('PRFLAN_208', 'User class which can email links to items on site');
define('PRFLAN_209', 'Other Features');
define('PRFLAN_210', 'Comments/Posting');
define('PRFLAN_215', 'Class which can post &lt;script&gt; and similar tags');
define('PRFLAN_216', '(Requires HTML posting rights as well)');
define('PRFLAN_217', 'Filter HTML content');
define('PRFLAN_218', 'If \'off\', puts users at increased risk of XSS exploits posted by members of the above class, or prior to 0.7.24');
// Gap for 0.8 compatibility
define('PRFLAN_220', 'HTML Abuse filter (experimental)');
define('PRFLAN_221', 'Blocks some unmatched tags for those allowed to post HTML');


?>
